"use strict";
// This file contains the bits and bobs of the internal API for loading and interacting with Nx plugins.
// For the public API, used by plugin authors, see `./public-api.ts`.
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDefaultPlugins = exports.loadNxPluginInIsolation = exports.loadNxPluginsInIsolation = exports.nxPluginCache = exports.loadPlugin = exports.loadPlugins = void 0;
const path_1 = require("path");
const workspace_root_1 = require("../../utils/workspace-root");
const angular_json_1 = require("../../adapter/angular-json");
const plugin_pool_1 = require("./plugin-pool");
var worker_api_1 = require("./worker-api");
Object.defineProperty(exports, "loadPlugins", { enumerable: true, get: function () { return worker_api_1.loadPlugins; } });
Object.defineProperty(exports, "loadPlugin", { enumerable: true, get: function () { return worker_api_1.loadPlugin; } });
// Short lived cache (cleared between cmd runs)
// holding resolved nx plugin objects.
// Allows loaded plugins to not be reloaded when
// referenced multiple times.
exports.nxPluginCache = new Map();
/**
 * This loads plugins in isolation in their own worker so that they do not disturb other workers or the main process.
 */
async function loadNxPluginsInIsolation(plugins, root = workspace_root_1.workspaceRoot) {
    const result = [];
    plugins ??= [];
    plugins.unshift((0, path_1.join)(__dirname, '../../plugins/project-json/build-nodes/package-json-next-to-project-json'));
    // We push the nx core node plugins onto the end, s.t. it overwrites any other plugins
    plugins.push(...(await getDefaultPlugins(root)));
    const cleanupFunctions = [];
    for (const plugin of plugins) {
        const [loadedPluginPromise, cleanup] = loadNxPluginInIsolation(plugin, root);
        result.push(loadedPluginPromise);
        cleanupFunctions.push(cleanup);
    }
    return [
        await Promise.all(result),
        () => {
            for (const fn of cleanupFunctions) {
                fn();
            }
        },
    ];
}
exports.loadNxPluginsInIsolation = loadNxPluginsInIsolation;
function loadNxPluginInIsolation(plugin, root = workspace_root_1.workspaceRoot) {
    const cacheKey = JSON.stringify(plugin);
    if (exports.nxPluginCache.has(cacheKey)) {
        return exports.nxPluginCache.get(cacheKey);
    }
    const [loadingPlugin, cleanup] = (0, plugin_pool_1.loadRemoteNxPlugin)(plugin, root);
    exports.nxPluginCache.set(cacheKey, [loadingPlugin, cleanup]);
    return [loadingPlugin, cleanup];
}
exports.loadNxPluginInIsolation = loadNxPluginInIsolation;
async function getDefaultPlugins(root) {
    return [
        (0, path_1.join)(__dirname, '../../plugins/js'),
        (0, path_1.join)(__dirname, '../../plugins/target-defaults/target-defaults-plugin'),
        ...((0, angular_json_1.shouldMergeAngularProjects)(root, false)
            ? [(0, path_1.join)(__dirname, '../../adapter/angular-json')]
            : []),
        (0, path_1.join)(__dirname, '../../plugins/package-json-workspaces'),
        (0, path_1.join)(__dirname, '../../plugins/project-json/build-nodes/project-json'),
    ];
}
exports.getDefaultPlugins = getDefaultPlugins;
