"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateNodesError = exports.normalizeNxPlugin = exports.isNxPluginV1 = exports.isNxPluginV2 = void 0;
const node_path_1 = require("node:path");
const workspaces_1 = require("../../config/workspaces");
const globs_1 = require("../../utils/globs");
function isNxPluginV2(plugin) {
    return 'createNodes' in plugin || 'createDependencies' in plugin;
}
exports.isNxPluginV2 = isNxPluginV2;
function isNxPluginV1(plugin) {
    return 'processProjectGraph' in plugin || 'projectFilePatterns' in plugin;
}
exports.isNxPluginV1 = isNxPluginV1;
function normalizeNxPlugin(plugin) {
    if (isNxPluginV2(plugin)) {
        return plugin;
    }
    if (isNxPluginV1(plugin) && plugin.projectFilePatterns) {
        return {
            ...plugin,
            createNodes: [
                `*/**/${(0, globs_1.combineGlobPatterns)(plugin.projectFilePatterns)}`,
                (configFilePath) => {
                    const root = (0, node_path_1.dirname)(configFilePath);
                    return {
                        projects: {
                            [root]: {
                                name: (0, workspaces_1.toProjectName)(configFilePath),
                                targets: plugin.registerProjectTargets?.(configFilePath),
                            },
                        },
                    };
                },
            ],
        };
    }
    return plugin;
}
exports.normalizeNxPlugin = normalizeNxPlugin;
class CreateNodesError extends Error {
    constructor(msg, cause) {
        const message = `${msg} ${!cause
            ? ''
            : cause instanceof Error
                ? `\n\n\t Inner Error: ${cause.stack}`
                : cause}`;
        // These errors are thrown during a JS callback which is invoked via rust.
        // The errors messaging gets lost in the rust -> js -> rust transition, but
        // logging the error here will ensure that it is visible in the console.
        console.error(message);
        super(message, { cause });
    }
}
exports.CreateNodesError = CreateNodesError;
